==> hugo_0.52.orig.tar.gz: hugo-0.52/docs/content/en/commands/hugo_benchmark.md <==
---
date: 2018-11-05
title: "hugo benchmark"
slug: hugo_benchmark
url: /commands/hugo_benchmark/
---
## hugo benchmark

Benchmark Hugo by building a site a number of times.

### Synopsis

Hugo can build a site many times over and analyze the running process
creating a benchmark.

```
hugo benchmark [flags]
```

### Options

```
  -b, --baseURL string         hostname (and path) to the root, e.g. http://spf13.com/
  -D, --buildDrafts            include content marked as draft
  -E, --buildExpired           include expired content
  -F, --buildFuture            include content with publishdate in the future
      --cacheDir string        filesystem path to cache directory. Defaults: $TMPDIR/hugo_cache/
      --cleanDestinationDir    remove files from destination not found in static directories
  -c, --contentDir string      filesystem path to content directory
  -n, --count int              number of times to build the site (default 13)
      --cpuprofile string      path/filename for the CPU profile file
  -d, --destination string     filesystem path to write files to
      --disableKinds strings   disable different kind of pages (home, RSS etc.)
      --enableGitInfo          add Git revision, date and author info to the pages
      --forceSyncStatic        copy all files when static is changed.
      --gc                     enable to run some cleanup tasks (remove unused cache files) after the build
  -h, --help                   help for benchmark
      --i18n-warnings          print missing translations
      --ignoreCache            ignores the cache directory
  -l, --layoutDir string       filesystem path to layout directory
      --memprofile string      path/filename for the memory profile file
      --minify                 minify any supported output format (HTML, XML etc.)
      --noChmod                don't sync permission mode of files
      --noTimes                don't sync modification time of files
      --renderToMemory         render to memory (only useful for benchmark testing)
  -s, --source string          filesystem path to read files relative from
      --stepAnalysis           display memory and timing of different steps of the program
      --templateMetrics        display metrics about template executions
      --templateMetricsHints   calculate some improvement hints when combined with --templateMetrics
  -t, --theme string           theme to use (located in /themes/THEMENAME/)
      --themesDir string       filesystem path to themes directory
```

### Options inherited from parent commands

```
      --config string    config file (default is path/config.yaml|json|toml)
      --debug            debug output
      --log              enable Logging
      --logFile string   log File path (if set, logging enabled automatically)
      --quiet            build in quiet mode
  -v, --verbose          verbose output
      --verboseLog       verbose logging
```

### SEE ALSO

* [hugo](/commands/hugo/)	 - hugo builds your site

###### Auto generated by spf13/cobra on 5-Nov-2018

==> hugo_0.53.orig.tar.gz: hugo-0.53/docs/content/en/commands/hugo_benchmark.md <==
---
date: 2018-12-12
title: "hugo benchmark"
slug: hugo_benchmark
url: /commands/hugo_benchmark/
---
## hugo benchmark

Benchmark Hugo by building a site a number of times.

### Synopsis

Hugo can build a site many times over and analyze the running process
creating a benchmark.

```
hugo benchmark [flags]
```

### Options

```
  -b, --baseURL string         hostname (and path) to the root, e.g. http://spf13.com/
  -D, --buildDrafts            include content marked as draft
  -E, --buildExpired           include expired content
  -F, --buildFuture            include content with publishdate in the future
      --cacheDir string        filesystem path to cache directory. Defaults: $TMPDIR/hugo_cache/
      --cleanDestinationDir    remove files from destination not found in static directories
  -c, --contentDir string      filesystem path to content directory
  -n, --count int              number of times to build the site (default 13)
      --cpuprofile string      path/filename for the CPU profile file
  -d, --destination string     filesystem path to write files to
      --disableKinds strings   disable different kind of pages (home, RSS etc.)
      --enableGitInfo          add Git revision, date and author info to the pages
  -e, --environment string     build environment
      --forceSyncStatic        copy all files when static is changed.
      --gc                     enable to run some cleanup tasks (remove unused cache files) after the build
  -h, --help                   help for benchmark
      --i18n-warnings          print missing translations
      --ignoreCache            ignores the cache directory
  -l, --layoutDir string       filesystem path to layout directory
      --memprofile string      path/filename for the memory profile file
      --minify                 minify any supported output format (HTML, XML etc.)
      --noChmod                don't sync permission mode of files
      --noTimes                don't sync modification time of files
      --renderToMemory         render to memory (only useful for benchmark testing)
  -s, --source string          filesystem path to read files relative from
      --stepAnalysis           display memory and timing of different steps of the program
      --templateMetrics        display metrics about template executions
      --templateMetricsHints   calculate some improvement hints when combined with --templateMetrics
  -t, --theme string           theme to use (located in /themes/THEMENAME/)
      --themesDir string       filesystem path to themes directory
```

### Options inherited from parent commands

```
      --config string      config file (default is path/config.yaml|json|toml)
      --configDir string   config dir (default "config")
      --debug              debug output
      --log                enable Logging
      --logFile string     log File path (if set, logging enabled automatically)
      --quiet              build in quiet mode
  -v, --verbose            verbose output
      --verboseLog         verbose logging
```

### SEE ALSO

* [hugo](/commands/hugo/)	 - hugo builds your site

###### Auto generated by spf13/cobra on 12-Dec-2018
